==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dock-network-plugin/translations/dock-network-plugin_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>無線熱點</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>協議</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>安全類型</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>頻段</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>界面</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC 位址</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網路遮罩</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>主要 DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前置詞</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>已停用裝置</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連線但不能存取網路</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連線</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>已拔除網路線</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>正在驗證</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>取得 IP 位址中…</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已連線</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>已斷線</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>連線失敗</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>正在取得 IP 位址</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線網路 %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線網路 %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>已停用裝置</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>已拔除網路線</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連線</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連線但不能存取網路</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連接失敗</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>關閉有線網路</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>啟用有線網路</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>關閉無線網路</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>啟用無線網路</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>停用網路</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>啟用網路</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dock-network-plugin/translations/dock-network-plugin_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>連接到隱藏網路</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>連 接</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>請輸入網路名稱（SSID）</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>無線熱點</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>協議</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>安全類型</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>頻段</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>界面</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC 位址</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子網路遮罩</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>閘道器</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>主要 DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前置詞</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>已停用裝置</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連線但不能存取網路</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連線</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>已拔除網路線</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>正在驗證</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>取得 IP 位址中…</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已連線</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>已斷線</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>連線失敗</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>正在取得 IP 位址</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線網路 %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線網路 %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>已停用裝置</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>已拔除網路線</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連線</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連線但不能存取網路</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連接失敗</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>關閉有線網路</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>啟用有線網路</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>關閉無線網路</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>啟用無線網路</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>停用網路</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>啟用網路</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
</context>
</TS>
